pub struct KrakenFuturesBatchEditItem {
pub order: String,
pub order_tag: String,
pub order_id: Option<String>,
pub cli_ord_id: Option<String>,
pub size: Option<String>,
pub limit_price: Option<String>,
pub stop_price: Option<String>,
}Expand description
A batch edit item for POST /derivatives/api/v3/batchorder.
References
Fields
order: StringThe operation type, always “edit” for this item.
order_tag: StringAn order tag to correlate batch responses with requests.
order_id: Option<String>The venue order ID to edit.
cli_ord_id: Option<String>The client order ID to edit.
size: Option<String>New order size.
limit_price: Option<String>New limit price.
stop_price: Option<String>New stop price.
Implementations
Sourceimpl KrakenFuturesBatchEditItem
impl KrakenFuturesBatchEditItem
Sourcepub fn from_params(
params: KrakenFuturesEditOrderParams,
order_tag: impl Into<String>,
) -> Self
pub fn from_params( params: KrakenFuturesEditOrderParams, order_tag: impl Into<String>, ) -> Self
Creates a batch edit item from edit order params.